==> jc-1.4.0.tar.gz: soot/options/SMBOptions.h <==
// public class soot.options.SMBOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6861a59e580e2f6a soot_options_SMBOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_SMBOptions_H_
#define _JC_soot_options_SMBOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_SMBOptions$sub_refs	_jc_soot_options_SMBOptions$sub_refs;
typedef struct _jc_soot_options_SMBOptions$sub_nonrefs	_jc_soot_options_SMBOptions$sub_nonrefs;
typedef struct _jc_soot_options_SMBOptions$refs	_jc_soot_options_SMBOptions$refs;
typedef struct _jc_soot_options_SMBOptions$nonrefs	_jc_soot_options_SMBOptions$nonrefs;
typedef struct _jc_soot_options_SMBOptions$object	_jc_soot_options_SMBOptions$object;

typedef struct _jc_soot_options_SMBOptions$fields_struct	_jc_soot_options_SMBOptions$fields_struct;
typedef const struct _jc_soot_options_SMBOptions$vmethods	_jc_soot_options_SMBOptions$vmethods;
typedef const struct _jc_soot_options_SMBOptions$vtable	_jc_soot_options_SMBOptions$vtable;
typedef const struct _jc_soot_options_SMBOptions$vtype	_jc_soot_options_SMBOptions$vtype;

// Class fields structure
struct _jc_soot_options_SMBOptions$fields_struct {
	jint	allowed__5fmodifier__5fchanges__5fnone;
	jint	allowed__5fmodifier__5fchanges__5fsafe;
	jint	allowed__5fmodifier__5fchanges__5funsafe;
};
extern _jc_soot_options_SMBOptions$fields_struct _jc_soot_options_SMBOptions$class_fields;

// Constructors
extern void _jc_soot_options_SMBOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_SMBOptions$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_soot_options_SMBOptions$method$allowed__5fmodifier__5fchanges$992954724bd3d1a3(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
extern jboolean _jc_soot_options_SMBOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
extern jboolean _jc_soot_options_SMBOptions$method$insert__5fnull__5fchecks$a3d5d639bec3a609(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
extern jboolean _jc_soot_options_SMBOptions$method$insert__5fredundant__5fcasts$34d18a903f88707c(_jc_env *, struct _jc_soot_options_SMBOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_SMBOptions$method_info$allowed__5fmodifier__5fchanges$992954724bd3d1a3;
extern _jc_method _jc_soot_options_SMBOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_SMBOptions$method_info$insert__5fnull__5fchecks$a3d5d639bec3a609;
extern _jc_method _jc_soot_options_SMBOptions$method_info$insert__5fredundant__5fcasts$34d18a903f88707c;

// Virtual methods structure
struct _jc_soot_options_SMBOptions$vmethods {
	jint	(*allowed__5fmodifier__5fchanges$992954724bd3d1a3)(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
	jboolean	(*insert__5fnull__5fchecks$a3d5d639bec3a609)(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
	jboolean	(*insert__5fredundant__5fcasts$34d18a903f88707c)(_jc_env *, struct _jc_soot_options_SMBOptions$object *);
};

// Vtable
struct _jc_soot_options_SMBOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_SMBOptions$vmethods	soot_options_SMBOptions;
};

// Vtype
struct _jc_soot_options_SMBOptions$vtype {
	_jc_type			type;
	_jc_soot_options_SMBOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_SMBOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_SMBOptions$refs {
    _jc_soot_options_SMBOptions$sub_refs	soot_options_SMBOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_SMBOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_SMBOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_SMBOptions$sub_nonrefs	soot_options_SMBOptions;
};

// Object instance structure
struct _jc_soot_options_SMBOptions$object {
	_jc_soot_options_SMBOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_SMBOptions$vtype	*vtype;
	_jc_soot_options_SMBOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_SMBOptions$vtype _jc_soot_options_SMBOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_SMBOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_SMBOptions$class_object;

#endif	/* _JC_soot_options_SMBOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/SMBOptions.h <==
// public class soot.options.SMBOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6861a59e580e2f6a soot_options_SMBOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_SMBOptions_H_
#define _JC_soot_options_SMBOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_SMBOptions$sub_refs	_jc_soot_options_SMBOptions$sub_refs;
typedef struct _jc_soot_options_SMBOptions$sub_nonrefs	_jc_soot_options_SMBOptions$sub_nonrefs;
typedef struct _jc_soot_options_SMBOptions$refs	_jc_soot_options_SMBOptions$refs;
typedef struct _jc_soot_options_SMBOptions$nonrefs	_jc_soot_options_SMBOptions$nonrefs;
typedef struct _jc_soot_options_SMBOptions$object	_jc_soot_options_SMBOptions$object;

typedef struct _jc_soot_options_SMBOptions$fields_struct	_jc_soot_options_SMBOptions$fields_struct;
typedef const struct _jc_soot_options_SMBOptions$vmethods	_jc_soot_options_SMBOptions$vmethods;
typedef const struct _jc_soot_options_SMBOptions$vtable	_jc_soot_options_SMBOptions$vtable;
typedef const struct _jc_soot_options_SMBOptions$vtype	_jc_soot_options_SMBOptions$vtype;

// Class fields structure
struct _jc_soot_options_SMBOptions$fields_struct {
	jint	allowed__5fmodifier__5fchanges__5fnone;
	jint	allowed__5fmodifier__5fchanges__5fsafe;
	jint	allowed__5fmodifier__5fchanges__5funsafe;
};
extern _jc_soot_options_SMBOptions$fields_struct _jc_soot_options_SMBOptions$class_fields;

// Constructors
extern void _jc_soot_options_SMBOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_SMBOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_options_SMBOptions$method$allowed__5fmodifier__5fchanges$992954724bd3d1a3(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SMBOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SMBOptions$method$insert__5fnull__5fchecks$a3d5d639bec3a609(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_SMBOptions$method$insert__5fredundant__5fcasts$34d18a903f88707c(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_SMBOptions$method_info$allowed__5fmodifier__5fchanges$992954724bd3d1a3;
extern _jc_method _jc_soot_options_SMBOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_SMBOptions$method_info$insert__5fnull__5fchecks$a3d5d639bec3a609;
extern _jc_method _jc_soot_options_SMBOptions$method_info$insert__5fredundant__5fcasts$34d18a903f88707c;

// Virtual methods structure
struct _jc_soot_options_SMBOptions$vmethods {
	jint	(*allowed__5fmodifier__5fchanges$992954724bd3d1a3)(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*insert__5fnull__5fchecks$a3d5d639bec3a609)(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*insert__5fredundant__5fcasts$34d18a903f88707c)(_jc_env *, struct _jc_soot_options_SMBOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_SMBOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_SMBOptions$vmethods	soot_options_SMBOptions;
};

// Vtype
struct _jc_soot_options_SMBOptions$vtype {
	_jc_type			type;
	_jc_soot_options_SMBOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_SMBOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_SMBOptions$refs {
    _jc_soot_options_SMBOptions$sub_refs	soot_options_SMBOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_SMBOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_SMBOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_SMBOptions$sub_nonrefs	soot_options_SMBOptions;
};

// Object instance structure
struct _jc_soot_options_SMBOptions$object {
	_jc_soot_options_SMBOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_SMBOptions$vtype	*vtype;
	_jc_soot_options_SMBOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_SMBOptions$vtype _jc_soot_options_SMBOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_SMBOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_SMBOptions$class_object;

#endif	/* _JC_soot_options_SMBOptions_H_ */
